==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiWidgets/QAbstractItemDelegate_shell.h <==
#ifndef QABSTRACTITEMDELEGATE_SHELL_H
#define QABSTRACTITEMDELEGATE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(itemviews)

class QAbstractItemDelegate_shell : public QAbstractItemDelegate, public QtJambiShellInterface
{
public:
    QAbstractItemDelegate_shell(QObject* parent0 = nullptr);
    ~QAbstractItemDelegate_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* createEditor(QWidget* parent0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    void customEvent(QEvent* event0) override;
    void destroyEditor(QWidget* editor0, const QModelIndex& index1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool editorEvent(QEvent* event0, QAbstractItemModel* model1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool helpEvent(QHelpEvent* event0, QAbstractItemView* view1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    void paint(QPainter* painter0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    QVector<int> paintingRoles() const override;
    void setEditorData(QWidget* editor0, const QModelIndex& index1) const override;
    void setModelData(QWidget* editor0, QAbstractItemModel* model1, const QModelIndex& index2) const override;
    QSize sizeHint(const QStyleOptionViewItem& option0, const QModelIndex& index1) const override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorGeometry(QWidget* editor0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractItemDelegate_access : public QAbstractItemDelegate
{
    jobject __qt_createEditor_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    void __qt_destroyEditor_QWidget_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID index1) const;
    jboolean __qt_editorEvent_QEvent_ptr_QAbstractItemModel_ptr_cref_QStyleOptionViewItem_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID model1, QtJambiNativeID option2, QtJambiNativeID index3);
    jboolean __qt_helpEvent_QHelpEvent_ptr_QAbstractItemView_ptr_cref_QStyleOptionViewItem_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID view1, QtJambiNativeID option2, QtJambiNativeID index3);
    void __qt_paint_QPainter_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    jobject __qt_paintingRoles(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setEditorData_QWidget_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID index1) const;
    void __qt_setModelData_QWidget_ptr_QAbstractItemModel_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID model1, QtJambiNativeID index2) const;
    jobject __qt_sizeHint_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID index1) const;
    void __qt_updateEditorGeometry_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID option1, QtJambiNativeID index2) const;
};

#endif // QT_CONFIG(itemviews)
#endif // QABSTRACTITEMDELEGATE_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiWidgets/QAbstractItemDelegate_shell.h <==
#ifndef QABSTRACTITEMDELEGATE_SHELL_H
#define QABSTRACTITEMDELEGATE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemdelegate.h>
#endif //QT_CONFIG(itemviews)
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/QVector>
#include <qtcore-config.h>
#if QT_CONFIG(itemmodel)
#include <QtCore/qabstractitemmodel.h>
#endif //QT_CONFIG(itemmodel)
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qevent.h>
#include <QtGui/qpainter.h>
#if QT_CONFIG(itemviews)
#include <QtWidgets/qabstractitemview.h>
#endif //QT_CONFIG(itemviews)
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(itemviews)

class QAbstractItemDelegate_shell : public QAbstractItemDelegate, public QtJambiShellInterface
{
public:
    QAbstractItemDelegate_shell(QObject* parent0 = nullptr);
    ~QAbstractItemDelegate_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QWidget* createEditor(QWidget* parent0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    void customEvent(QEvent* event0) override;
    void destroyEditor(QWidget* editor0, const QModelIndex& index1) const override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool editorEvent(QEvent* event0, QAbstractItemModel* model1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool helpEvent(QHelpEvent* event0, QAbstractItemView* view1, const QStyleOptionViewItem& option2, const QModelIndex& index3) override;
    void paint(QPainter* painter0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    QVector<int> paintingRoles() const override;
    void setEditorData(QWidget* editor0, const QModelIndex& index1) const override;
    void setModelData(QWidget* editor0, QAbstractItemModel* model1, const QModelIndex& index2) const override;
    QSize sizeHint(const QStyleOptionViewItem& option0, const QModelIndex& index1) const override;
    void timerEvent(QTimerEvent* event0) override;
    void updateEditorGeometry(QWidget* editor0, const QStyleOptionViewItem& option1, const QModelIndex& index2) const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractItemDelegate_access : public QAbstractItemDelegate
{
    jobject __qt_createEditor_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID parent0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    void __qt_destroyEditor_QWidget_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID index1) const;
    jboolean __qt_editorEvent_QEvent_ptr_QAbstractItemModel_ptr_cref_QStyleOptionViewItem_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID model1, QtJambiNativeID option2, QtJambiNativeID index3);
    jboolean __qt_helpEvent_QHelpEvent_ptr_QAbstractItemView_ptr_cref_QStyleOptionViewItem_cref_QModelIndex(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID event0, QtJambiNativeID view1, QtJambiNativeID option2, QtJambiNativeID index3);
    void __qt_paint_QPainter_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0, QtJambiNativeID option1, QtJambiNativeID index2) const;
    jobject __qt_paintingRoles_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_setEditorData_QWidget_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID index1) const;
    void __qt_setModelData_QWidget_ptr_QAbstractItemModel_ptr_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID model1, QtJambiNativeID index2) const;
    jobject __qt_sizeHint_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID option0, QtJambiNativeID index1) const;
    void __qt_updateEditorGeometry_QWidget_ptr_cref_QStyleOptionViewItem_cref_QModelIndex_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID editor0, QtJambiNativeID option1, QtJambiNativeID index2) const;
};

#endif // QT_CONFIG(itemviews)
#endif // QABSTRACTITEMDELEGATE_SHELL_H
